@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2019 Andrew Ziem
+# Copyright (C) 2008-2020 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 Perform (or assist with) cleaning operations.
 """
 
-from __future__ import absolute_import # keep at top
+from __future__ import absolute_import  # keep at top
 
 import glob
 import logging
@@ -41,9 +41,10 @@ warnings.simplefilter("ignore", Warning)
 try:
     from bleachbit.GuiBasic import Gtk, Gdk
     HAVE_GTK = Gdk.get_default_root_window() is not None
-except (ImportError, RuntimeError) as e:
+except (ImportError, RuntimeError, ValueError) as e:
     # ImportError happens when GTK is not installed.
     # RuntimeError can happen when X is not available (e.g., cron, ssh).
+    # ValueError seen on BleachBit 3.0 with GTK 3 (GitHub issue 685)
     HAVE_GTK = False
 
 
@@ -550,6 +551,7 @@ class System(Cleaner):
         if HAVE_GTK and 'clipboard' == option_id:
             def clear_clipboard():
                 clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
+                clipboard.set_text(' ',1)
                 clipboard.clear()
                 return 0
             yield Command.Function(None, clear_clipboard, _('Clipboard'))
@@ -607,7 +609,8 @@ class System(Cleaner):
                 try:
                     Windows.empty_recycle_bin(None, True)
                 except:
-                    logging.getLogger(__name__).info('error in empty_recycle_bin()', exc_info=True)
+                    logging.getLogger(__name__).info(
+                        'error in empty_recycle_bin()', exc_info=True)
                 yield 0
             # Using the Function Command prevents emptying the recycle bin
             # when in preview mode.
@@ -667,7 +670,7 @@ class System(Cleaner):
         return False
 
 
-def register_cleaners(cb_progress = lambda x: None, cb_done = lambda: None):
+def register_cleaners(cb_progress=lambda x: None, cb_done=lambda: None):
     """Register all known cleaners: system, CleanerML, and Winapp2"""
     global backends
 
@@ -694,7 +697,7 @@ def register_cleaners(cb_progress = lambda x: None, cb_done = lambda: None):
 
     cb_done()
 
-    yield False # end the iteration
+    yield False  # end the iteration
 
 
 def create_simple_cleaner(paths):
