@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2019 Andrew Ziem
+# Copyright (C) 2008-2020 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 Command design pattern implementation for cleaning
 """
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import
 
 from bleachbit import _
 from bleachbit import FileUtilities
@@ -310,9 +310,10 @@ class Winreg:
         if self.valuename:
             _str = '%s<%s>' % (self.keyname, self.valuename)
             ret = bleachbit.Windows.delete_registry_value(self.keyname,
-                                                self.valuename, really_delete)
+                                                          self.valuename, really_delete)
         else:
-            ret = bleachbit.Windows.delete_registry_key(self.keyname, really_delete)
+            ret = bleachbit.Windows.delete_registry_key(
+                self.keyname, really_delete)
             _str = self.keyname
         if not ret:
             # Nothing to delete or nothing was deleted.  This return
