@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2019 Andrew Ziem
+# Copyright (C) 2008-2020 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -92,7 +92,8 @@ class DeepScan:
 
     def scan(self):
         """Perform requested searches and yield each match"""
-        logging.getLogger(__name__).debug('DeepScan.scan: searches=%s', str(self.searches))
+        logging.getLogger(__name__).debug(
+            'DeepScan.scan: searches=%s', str(self.searches))
         import time
         yield_time = time.time()
 
