@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 
 # BleachBit
-# Copyright (C) 2008-2019 Andrew Ziem
+# Copyright (C) 2008-2020 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -273,7 +273,7 @@ def wipe_swap_linux(devices, proc_swaps):
     if 0 < count_swap_linux():
         raise RuntimeError('Cannot wipe swap while it is in use')
     for device in devices:
-        #if '/cryptswap' in device:
+        # if '/cryptswap' in device:
         #    logger.info('Skipping encrypted swap device %s.', device)
         #    continue
         # TRANSLATORS: The variable is a device like /dev/sda2
@@ -313,9 +313,9 @@ def wipe_memory():
     if 0 == child_pid:
         make_self_oom_target_linux()
         fill_memory_linux()
-        sys.exit(0)
+        os._exit(0)
     else:
-# TRANSLATORS: This is a debugging message that the parent process is waiting for the child process.
+        # TRANSLATORS: This is a debugging message that the parent process is waiting for the child process.
         logger.debug(_("The function wipe_memory() with process ID {pid} is waiting for child process ID {cid}.").format(
                      pid=os.getpid(), cid=child_pid))
         rc = os.waitpid(child_pid, 0)[1]
