@@ -1,7 +1,7 @@
 # vim: ts=4:sw=4:expandtab
 
 # BleachBit
-# Copyright (C) 2008-2018 Andrew Ziem
+# Copyright (C) 2008-2020 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 Check for updates via the Internet
 """
 
-from __future__ import absolute_import, print_function
+from __future__ import absolute_import
 
 import bleachbit
 from bleachbit import _
@@ -34,13 +34,13 @@ import os.path
 import platform
 import socket
 import sys
+import xml.dom.minidom
 if sys.version >= (3, 0):
     from urllib.request import build_opener
     from urllib.error import URLError
 else:
     from urllib2 import build_opener, URLError
 
-import xml.dom.minidom
 
 logger = logging.getLogger(__name__)
 
@@ -108,8 +108,8 @@ def user_agent():
         logger.exception('Exception when getting default locale')
 
     try:
-        import gtk
-        gtkver = '; GTK %s' % '.'.join([str(x) for x in gtk.gtk_version])
+        from gi.repository import Gtk
+        gtkver = '; GTK %s' % '.'.join([str(x) for x in Gtk.gtk_version])
     except:
         gtkver = ""
 
@@ -120,30 +120,31 @@ def user_agent():
 
 def update_dialog(parent, updates):
     """Updates contains the version numbers and URLs"""
-    import gtk
+    from gi.repository import Gtk
     from bleachbit.GuiBasic import open_url
-    dlg = gtk.Dialog(title=_("Update BleachBit"),
-                     parent=parent,
-                     flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
+    dlg = Gtk.Dialog(title=_("Update BleachBit"),
+                     transient_for=parent,
+                     modal=True,
+                     destroy_with_parent=True)
     dlg.set_default_size(250, 125)
 
-    label = gtk.Label(_("A new version is available."))
-    dlg.vbox.pack_start(label)
+    label = Gtk.Label(label=_("A new version is available."))
+    dlg.vbox.pack_start(label, True, True, 0)
 
     for update in updates:
         ver = update[0]
         url = update[1]
-        box_update = gtk.HBox()
+        box_update = Gtk.Box()
         # TRANSLATORS: %s expands to version such as '0.8.4' or '0.8.5beta' or
         # similar
-        button_stable = gtk.Button(_("Update to version %s") % ver)
+        button_stable = Gtk.Button(_("Update to version %s") % ver)
         button_stable.connect(
             'clicked', lambda dummy: open_url(url, parent, False))
         button_stable.connect('clicked', lambda dummy: dlg.response(0))
-        box_update.pack_start(button_stable, False, padding=10)
-        dlg.vbox.pack_start(box_update, False)
+        box_update.pack_start(button_stable, False, True, 10)
+        dlg.vbox.pack_start(box_update, False, True, 0)
 
-    dlg.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
+    dlg.add_button(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
 
     dlg.show_all()
     dlg.run()
@@ -159,10 +160,9 @@ def check_updates(check_beta, check_winapp2, append_text, cb_success):
     opener.addheaders = [('User-Agent', user_agent())]
     try:
         handle = opener.open(bleachbit.update_check_url)
-    except URLError:
-        logger.exception(
-            _('Error when opening a network connection to %s to check for updates. Please verify the network is working.' %
-                bleachbit.update_check_url))
+    except URLError as e:
+        logger.error(
+            _('Error when opening a network connection to check for updates. Please verify the network is working and that a firewall is not blocking this application. Error message: {}').format(e))
         return ()
     doc = handle.read()
     try:
